# -*- coding: utf-8 -*-
# pylint: disable=invalid-name
#
# Configuration file for the Sphinx documentation builder.
#
# This file does only contain a selection of the most common options. For a
# full list see the documentation:
# http://www.sphinx-doc.org/en/master/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

from shm_dict._version import __version__  # pylint: disable=wrong-import-position

# Add base directory to path
# (shm_dict/docs/source/conf.py -> shm_dict/docs/source -> shm_dict/docs -> shm_dict)
sys.path.insert(
    0, os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
)


# -- Project information -----------------------------------------------------

project = "Shared Memory Dictionary"
copyright = "2019, Nate Bohman"  # pylint: disable=redefined-builtin
author = "Nate Bohman"

# The short X.Y version
# version = ''
version = __version__
# The full version, including alpha/beta/rc tags
# release = '2018.10.25.12.00'
release = __version__

# -- General configuration ---------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx_automodapi.automodapi",
    "sphinx_automodapi.smart_resolver",
    "sphinx.ext.autodoc",
    "sphinx.ext.doctest",
    "sphinx.ext.inheritance_diagram",
    "sphinx.ext.intersphinx",
    "sphinx.ext.todo",
    "sphinx.ext.coverage",
    "sphinx.ext.imgmath",
    "sphinx.ext.ifconfig",
    "sphinx.ext.viewcode",
    "sphinx.ext.githubpages",
    "sphinx.ext.napoleon",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

# List of warnings to suppress when generating documentation.
suppress_warnings = [
    "misc.highlighting_failure",
    "ref.doc",
    "ref.numref",
    "ref.ref",
    "toc.secnum",
]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "alabaster"

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# The default sidebars (for documents that don't match any pattern) are
# defined by theme itself.  Builtin themes are using these templates by
# default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
# 'searchbox.html']``.
#
# html_sidebars = {}

# -- Options for HTMLHelp output ---------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "SharedMemoryDictionarydoc"


# -- Options for LaTeX output ------------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',
    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',
    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (
        master_doc,
        "SharedMemoryDictionary.tex",
        "Shared Memory Dictionary Documentation",
        "Nate Bohman",
        "manual",
    )
]


# -- Options for manual page output ------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, "shm_dict", "Shared Memory Dictionary Documentation", [author], 1)
]


# -- Options for Texinfo output ----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "shm_dict",
        "Shared Memory Dictionary Documentation",
        author,
        "SharedMemoryDictionary",
        "Shared Memory Dictionary Documentation.",
        "Miscellaneous",
    )
]


# -- Options for Epub output -------------------------------------------------

# Bibliographic Dublin Core info.
epub_title = project

# The unique identifier of the text. This can be a ISBN number
# or the project homepage.
#
# epub_identifier = ''

# A unique identification for the text.
#
# epub_uid = ''

# A list of files that should not be packed into the epub file.
epub_exclude_files = ["search.html"]


# -- Extension configuration -------------------------------------------------

# -- Options for intersphinx extension ---------------------------------------

# Example configuration for intersphinx: refer to the Python standard library.
# The URL is the first tuple item. Check with
# "python -m sphinx.ext.intersphinx 'URL/objects.inv'"
# and use the second tuple item to specify the
# name if not the default objects.inv
intersphinx_mapping = {
    "arrow": ("https://arrow.readthedocs.io/en/latest/", None),
    "py2": ("https://docs.python.org/2", None),
    "py3": ("https://docs.python.org/3", None),
    "python": ("https://docs.python.org/3", None),
    "requests": ("http://docs.python-requests.org/en/master/", None),
    "six": ("https://six.readthedocs.io/", None),
    "urllib3": ("https://urllib3.readthedocs.io/en/latest/", None),
}

# -- Options for todo extension ----------------------------------------------

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True

# -- Options for autodoc extension -------------------------------------------

autodoc_default_options = {
    "member-order": "bysource",
    "special-members": "__init__",
    "exclude-members": "__weakref__",
    "show-inheritance": None,
}

# -- Options for automodapi extension ----------------------------------------

# This is needed to avoid having methods and attributes of classes
# being shown multiple times.
numpydoc_show_class_members = False

# If True, members that a class inherits from a base class are included
# in the generated documentation.
# automodsumm_inherited_members = False

# -- Options for inheritance-graph extension ---------------------------------

inheritance_graph_attrs = dict(
    fontsize=14, size=200, splines="spline", ratio="auto", rankdir="LR"
)
inheritance_node_attrs = dict(shape="ellipse", fontsize=14, height=0.75)


# Add custom stylesheets
def setup(app):
    app.add_stylesheet("css/coverage.css")
